==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/RefreshCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RefreshCompletedEventArgsDescription } from "./RefreshCompletedEventArgsDescription";
/**
 * @hidden
 */
export let RefreshCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RefreshCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RefreshCompletedEventArgsDescriptionMetadata.a == null) {
                RefreshCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RefreshCompletedEventArgsDescriptionMetadata.c(RefreshCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RefreshCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(RefreshCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            RefreshCompletedEventArgsDescriptionMetadata.b(a);
            a.ad("RefreshCompletedEventArgs", () => new RefreshCompletedEventArgsDescription());
            a.ac("RefreshCompletedEventArgs", RefreshCompletedEventArgsDescriptionMetadata.a);
        }
    }
    RefreshCompletedEventArgsDescriptionMetadata.$t = markType(RefreshCompletedEventArgsDescriptionMetadata, 'RefreshCompletedEventArgsDescriptionMetadata');
    RefreshCompletedEventArgsDescriptionMetadata.a = null;
    return RefreshCompletedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/RefreshCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RefreshCompletedEventArgsDescription } from "./RefreshCompletedEventArgsDescription";
/**
 * @hidden
 */
export let RefreshCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RefreshCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RefreshCompletedEventArgsDescriptionMetadata.a == null) {
                RefreshCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RefreshCompletedEventArgsDescriptionMetadata.c(RefreshCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RefreshCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(RefreshCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            RefreshCompletedEventArgsDescriptionMetadata.b(a);
            a.ae("RefreshCompletedEventArgs", () => new RefreshCompletedEventArgsDescription());
            a.ad("RefreshCompletedEventArgs", RefreshCompletedEventArgsDescriptionMetadata.a);
        }
    }
    RefreshCompletedEventArgsDescriptionMetadata.$t = markType(RefreshCompletedEventArgsDescriptionMetadata, 'RefreshCompletedEventArgsDescriptionMetadata');
    RefreshCompletedEventArgsDescriptionMetadata.a = null;
    return RefreshCompletedEventArgsDescriptionMetadata;
})();
